using System;
using System.Collections.Generic;
using Microsoft.AspNetCore.Mvc;

namespace WebAPISampleApp.Controllers
{
    [Route("beers")]
    public class BeersController
    {
        public class Beer
        {
            public string BeerName { get; set; }
            public long BeerId { get; set; }
            public override string ToString()
            {
                return "BeerName: " + BeerName + " BeerId: " + BeerId;
            }
        }

        private static List<Beer> savedBeers = new List<Beer>();
        private static long nextBeerId = 1;

        // GET api/beers
        [HttpGet]
        public string Get()
        {
            string beers = String.Join<Beer>(", ", savedBeers.ToArray());
            return (beers.Length == 0) ? "No beers" : beers;
        }

        // GET api/beers/{id}
        [HttpGet("{id}")]
        public string Get(long id)
        {
            int index = FindBeerById(id);
            if (index != -1) 
            {
                return savedBeers[index].ToString();
            }
            return "Beer Not Found";
        }

        // POST api/beers
        [HttpPost]
        public void Post([FromBody]Beer beer)
        {
            beer.BeerId = nextBeerId++;
            savedBeers.Add(beer);
        }

        // PUT api/beers
        [HttpPut]
        public void PUT([FromBody]Beer beer)
        {
            int index = FindBeerById(beer.BeerId);

            if (index != -1)
            {
                savedBeers[index].BeerName = beer.BeerName;
            }
        }

        // DELETE api/beers/{id}
        [HttpDelete("{id}")]
        public void Delete(long id)
        {
            int index = FindBeerById(id);

            if (index != -1)
            {
                savedBeers.RemoveAt(index);
            }
        }


        private int FindBeerById(long id)
        {
            int i = 0;
            while (i < savedBeers.Count)
            {
                if (savedBeers[i].BeerId == id)
                {
                    break;
                }
                i++;
            }

            if (i != savedBeers.Count)
            {
                return i;
            } else
            {
                return -1;
            }
        }
    }
}
